==> unit-1.0.49-sources.jar: io/intino/goros/unit/box/ui/displays/items/SourceLevelListItem.java <==
package io.intino.goros.unit.box.ui.displays.items;

import io.intino.alexandria.core.Box;
import io.intino.alexandria.exceptions.*;
import io.intino.alexandria.ui.displays.components.*;
import io.intino.goros.unit.box.ui.*;

import io.intino.goros.unit.box.UnitBox;

import io.intino.goros.unit.box.ui.displays.templates.*;






import io.intino.goros.unit.box.ui.displays.items.*;
import io.intino.goros.unit.box.ui.displays.rows.*;
import io.intino.alexandria.ui.displays.notifiers.ItemNotifier;

public class SourceLevelListItem extends io.intino.alexandria.ui.displays.components.Item<ItemNotifier, org.monet.space.kernel.model.Term, UnitBox> {
	public _32_4_1324018084 _32_4_1324018084;
	public SourceLevelListItem._32_4_1324018084. DisabledLayer disabledLayer;
	public SourceLevelListItem._32_4_1324018084. _34_5_01546744121 _34_5_01546744121;
	public SourceLevelListItem._32_4_1324018084._34_5_01546744121. _35_6_01699575602 _35_6_01699575602;
	public SourceLevelListItem._32_4_1324018084._34_5_01546744121._35_6_01699575602. Type type;
	public SourceLevelListItem._32_4_1324018084._34_5_01546744121._35_6_01699575602. Label label;
	public SourceLevelListItem._32_4_1324018084._34_5_01546744121. Code code;
	public SourceLevelListItem._32_4_1324018084._34_5_01546744121. TagsCount tagsCount;
	public SourceLevelListItem._32_4_1324018084. _40_5_0855064589 _40_5_0855064589;
	public SourceLevelListItem._32_4_1324018084._40_5_0855064589. GroupFlag groupFlag;

    public SourceLevelListItem(UnitBox box) {
        super(box);
        id("a522535855");
    }

    @Override
	public void init() {
		super.init();
		if (_32_4_1324018084 == null) _32_4_1324018084 = register(new _32_4_1324018084(box()).<_32_4_1324018084>id("a_1572001419").owner(SourceLevelListItem.this));
		if (_32_4_1324018084 != null) disabledLayer = _32_4_1324018084.disabledLayer;
		if (_32_4_1324018084 != null) _34_5_01546744121 = _32_4_1324018084._34_5_01546744121;
		if (_34_5_01546744121 != null) _35_6_01699575602 = _32_4_1324018084._34_5_01546744121._35_6_01699575602;
		if (_35_6_01699575602 != null) type = _32_4_1324018084._34_5_01546744121._35_6_01699575602.type;
		if (_35_6_01699575602 != null) label = _32_4_1324018084._34_5_01546744121._35_6_01699575602.label;
		if (_34_5_01546744121 != null) code = _32_4_1324018084._34_5_01546744121.code;
		if (_34_5_01546744121 != null) tagsCount = _32_4_1324018084._34_5_01546744121.tagsCount;
		if (_32_4_1324018084 != null) _40_5_0855064589 = _32_4_1324018084._40_5_0855064589;
		if (_40_5_0855064589 != null) groupFlag = _32_4_1324018084._40_5_0855064589.groupFlag;
	}

	public class _32_4_1324018084 extends io.intino.alexandria.ui.displays.components.Block<io.intino.alexandria.ui.displays.notifiers.BlockNotifier, UnitBox>  {
		public SourceLevelListItem._32_4_1324018084. DisabledLayer disabledLayer;
		public SourceLevelListItem._32_4_1324018084. _34_5_01546744121 _34_5_01546744121;
		public SourceLevelListItem._32_4_1324018084. _40_5_0855064589 _40_5_0855064589;

		public _32_4_1324018084(UnitBox box) {
			super(box);
		}

		@Override
		public void init() {
			super.init();
			if (disabledLayer == null) disabledLayer = register(new DisabledLayer(box()).<DisabledLayer>id("a514512910").owner(SourceLevelListItem.this));
			if (_34_5_01546744121 == null) _34_5_01546744121 = register(new _34_5_01546744121(box()).<_34_5_01546744121>id("a127833215").owner(SourceLevelListItem.this));
			if (_40_5_0855064589 == null) _40_5_0855064589 = register(new _40_5_0855064589(box()).<_40_5_0855064589>id("a_367719579").owner(SourceLevelListItem.this));
		}

		public class DisabledLayer extends io.intino.alexandria.ui.displays.components.Block<io.intino.alexandria.ui.displays.notifiers.BlockNotifier, UnitBox>  {

			public DisabledLayer(UnitBox box) {
				super(box);
			}

			@Override
			public void init() {
				super.init();
			}
		}

		public class _34_5_01546744121 extends io.intino.alexandria.ui.displays.components.Block<io.intino.alexandria.ui.displays.notifiers.BlockNotifier, UnitBox>  {
			public SourceLevelListItem._32_4_1324018084._34_5_01546744121. _35_6_01699575602 _35_6_01699575602;
			public SourceLevelListItem._32_4_1324018084._34_5_01546744121. Code code;
			public SourceLevelListItem._32_4_1324018084._34_5_01546744121. TagsCount tagsCount;

			public _34_5_01546744121(UnitBox box) {
				super(box);
			}

			@Override
			public void init() {
				super.init();
				if (_35_6_01699575602 == null) _35_6_01699575602 = register(new _35_6_01699575602(box()).<_35_6_01699575602>id("a1844932431").owner(SourceLevelListItem.this));
				if (code == null) code = register(new Code(box()).<Code>id("a_1929643951").owner(SourceLevelListItem.this));
				if (tagsCount == null) tagsCount = register(new TagsCount(box()).<TagsCount>id("a_122853230").owner(SourceLevelListItem.this));
			}

			public class _35_6_01699575602 extends io.intino.alexandria.ui.displays.components.Block<io.intino.alexandria.ui.displays.notifiers.BlockNotifier, UnitBox>  {
				public SourceLevelListItem._32_4_1324018084._34_5_01546744121._35_6_01699575602. Type type;
				public SourceLevelListItem._32_4_1324018084._34_5_01546744121._35_6_01699575602. Label label;

				public _35_6_01699575602(UnitBox box) {
					super(box);
				}

				@Override
				public void init() {
					super.init();
					if (type == null) type = register(new Type(box()).<Type>id("a_157688036").owner(SourceLevelListItem.this));
					if (label == null) label = register(new Label(box()).<Label>id("a_601478318").owner(SourceLevelListItem.this));
				}

				public class Type extends io.intino.alexandria.ui.displays.components.Text<io.intino.alexandria.ui.displays.notifiers.TextNotifier, UnitBox>  {

					public Type(UnitBox box) {
						super(box);
					}

					@Override
					public void init() {
						super.init();
					}
					public Type textColor(String color) {
					    this._textColor(color);
					    this._refreshHighlight();
					    return this;
					}

					public Type backgroundColor(String color) {
					    this._backgroundColor(color);
					    this._refreshHighlight();
					    return this;
					}
				}

				public class Label extends io.intino.alexandria.ui.displays.components.Text<io.intino.alexandria.ui.displays.notifiers.TextNotifier, UnitBox>  {

					public Label(UnitBox box) {
						super(box);
					}

					@Override
					public void init() {
						super.init();
					}
				}
			}

			public class Code extends io.intino.alexandria.ui.displays.components.Text<io.intino.alexandria.ui.displays.notifiers.TextNotifier, UnitBox>  {

				public Code(UnitBox box) {
					super(box);
				}

				@Override
				public void init() {
					super.init();
				}
			}

			public class TagsCount extends io.intino.alexandria.ui.displays.components.Number<io.intino.alexandria.ui.displays.notifiers.NumberNotifier, UnitBox>  {

				public TagsCount(UnitBox box) {
					super(box);
					label("Tags count");
					_value(0.0);
				}

				@Override
				public void init() {
					super.init();
				}
			}
		}

		public class _40_5_0855064589 extends io.intino.alexandria.ui.displays.components.Block<io.intino.alexandria.ui.displays.notifiers.BlockNotifier, UnitBox>  {
			public SourceLevelListItem._32_4_1324018084._40_5_0855064589. GroupFlag groupFlag;

			public _40_5_0855064589(UnitBox box) {
				super(box);
			}

			@Override
			public void init() {
				super.init();
				if (groupFlag == null) groupFlag = register(new GroupFlag(box()).<GroupFlag>id("a737957442").owner(SourceLevelListItem.this));
			}

			public class GroupFlag extends io.intino.alexandria.ui.displays.components.MaterialIcon<io.intino.alexandria.ui.displays.notifiers.MaterialIconNotifier, UnitBox>  {

				public GroupFlag(UnitBox box) {
					super(box);
					_icon("KeyboardArrowRight");
				}

				@Override
				public void init() {
					super.init();
				}
			}
		}
	}
}

==> unit-1.1.1-sources.jar: io/intino/goros/unit/box/ui/displays/items/SourceLevelListItem.java <==
package io.intino.goros.unit.box.ui.displays.items;

import io.intino.alexandria.core.Box;
import io.intino.alexandria.exceptions.*;
import io.intino.alexandria.ui.displays.components.*;
import io.intino.goros.unit.box.ui.*;

import io.intino.goros.unit.box.UnitBox;

import io.intino.goros.unit.box.ui.displays.templates.*;






import io.intino.goros.unit.box.ui.displays.items.*;
import io.intino.goros.unit.box.ui.displays.rows.*;
import io.intino.alexandria.ui.displays.notifiers.ItemNotifier;

public class SourceLevelListItem extends io.intino.alexandria.ui.displays.components.Item<ItemNotifier, org.monet.space.kernel.model.Term, UnitBox> {
	public _32_4_1324018084 _32_4_1324018084;
	public SourceLevelListItem._32_4_1324018084. DisabledLayer disabledLayer;
	public SourceLevelListItem._32_4_1324018084. _34_5_01546744121 _34_5_01546744121;
	public SourceLevelListItem._32_4_1324018084._34_5_01546744121. _35_6_01699575602 _35_6_01699575602;
	public SourceLevelListItem._32_4_1324018084._34_5_01546744121._35_6_01699575602. Type type;
	public SourceLevelListItem._32_4_1324018084._34_5_01546744121._35_6_01699575602. Label label;
	public SourceLevelListItem._32_4_1324018084._34_5_01546744121. Code code;
	public SourceLevelListItem._32_4_1324018084._34_5_01546744121. TagsCount tagsCount;
	public SourceLevelListItem._32_4_1324018084. _40_5_0855064589 _40_5_0855064589;
	public SourceLevelListItem._32_4_1324018084._40_5_0855064589. GroupFlag groupFlag;

    public SourceLevelListItem(UnitBox box) {
        super(box);
        id("a522535855");
    }

    @Override
	public void init() {
		super.init();
		if (_32_4_1324018084 == null) _32_4_1324018084 = register(new _32_4_1324018084(box()).<_32_4_1324018084>id("a_1572001419").owner(SourceLevelListItem.this));
		if (_32_4_1324018084 != null) disabledLayer = _32_4_1324018084.disabledLayer;
		if (_32_4_1324018084 != null) _34_5_01546744121 = _32_4_1324018084._34_5_01546744121;
		if (_34_5_01546744121 != null) _35_6_01699575602 = _32_4_1324018084._34_5_01546744121._35_6_01699575602;
		if (_35_6_01699575602 != null) type = _32_4_1324018084._34_5_01546744121._35_6_01699575602.type;
		if (_35_6_01699575602 != null) label = _32_4_1324018084._34_5_01546744121._35_6_01699575602.label;
		if (_34_5_01546744121 != null) code = _32_4_1324018084._34_5_01546744121.code;
		if (_34_5_01546744121 != null) tagsCount = _32_4_1324018084._34_5_01546744121.tagsCount;
		if (_32_4_1324018084 != null) _40_5_0855064589 = _32_4_1324018084._40_5_0855064589;
		if (_40_5_0855064589 != null) groupFlag = _32_4_1324018084._40_5_0855064589.groupFlag;
	}

    @Override
    public void remove() {
        super.remove();
	    if (_32_4_1324018084 != null) _32_4_1324018084.unregister();
	}

	public class _32_4_1324018084 extends io.intino.alexandria.ui.displays.components.Block<io.intino.alexandria.ui.displays.notifiers.BlockNotifier, UnitBox>  {
		public SourceLevelListItem._32_4_1324018084. DisabledLayer disabledLayer;
		public SourceLevelListItem._32_4_1324018084. _34_5_01546744121 _34_5_01546744121;
		public SourceLevelListItem._32_4_1324018084. _40_5_0855064589 _40_5_0855064589;

		public _32_4_1324018084(UnitBox box) {
			super(box);
		}

		@Override
		public void init() {
			super.init();
			if (disabledLayer == null) disabledLayer = register(new DisabledLayer(box()).<DisabledLayer>id("a514512910").owner(SourceLevelListItem.this));
			if (_34_5_01546744121 == null) _34_5_01546744121 = register(new _34_5_01546744121(box()).<_34_5_01546744121>id("a127833215").owner(SourceLevelListItem.this));
			if (_40_5_0855064589 == null) _40_5_0855064589 = register(new _40_5_0855064589(box()).<_40_5_0855064589>id("a_367719579").owner(SourceLevelListItem.this));
		}

		@Override
		public void unregister() {
		    super.unregister();
			if (disabledLayer != null) disabledLayer.unregister();
			if (_34_5_01546744121 != null) _34_5_01546744121.unregister();
			if (_40_5_0855064589 != null) _40_5_0855064589.unregister();
		}

		public class DisabledLayer extends io.intino.alexandria.ui.displays.components.Block<io.intino.alexandria.ui.displays.notifiers.BlockNotifier, UnitBox>  {

			public DisabledLayer(UnitBox box) {
				super(box);
			}

			@Override
			public void init() {
				super.init();
			}

			@Override
			public void unregister() {
			    super.unregister();
			}
		}

		public class _34_5_01546744121 extends io.intino.alexandria.ui.displays.components.Block<io.intino.alexandria.ui.displays.notifiers.BlockNotifier, UnitBox>  {
			public SourceLevelListItem._32_4_1324018084._34_5_01546744121. _35_6_01699575602 _35_6_01699575602;
			public SourceLevelListItem._32_4_1324018084._34_5_01546744121. Code code;
			public SourceLevelListItem._32_4_1324018084._34_5_01546744121. TagsCount tagsCount;

			public _34_5_01546744121(UnitBox box) {
				super(box);
			}

			@Override
			public void init() {
				super.init();
				if (_35_6_01699575602 == null) _35_6_01699575602 = register(new _35_6_01699575602(box()).<_35_6_01699575602>id("a1844932431").owner(SourceLevelListItem.this));
				if (code == null) code = register(new Code(box()).<Code>id("a_1929643951").owner(SourceLevelListItem.this));
				if (tagsCount == null) tagsCount = register(new TagsCount(box()).<TagsCount>id("a_122853230").owner(SourceLevelListItem.this));
			}

			@Override
			public void unregister() {
			    super.unregister();
				if (_35_6_01699575602 != null) _35_6_01699575602.unregister();
				if (code != null) code.unregister();
				if (tagsCount != null) tagsCount.unregister();
			}

			public class _35_6_01699575602 extends io.intino.alexandria.ui.displays.components.Block<io.intino.alexandria.ui.displays.notifiers.BlockNotifier, UnitBox>  {
				public SourceLevelListItem._32_4_1324018084._34_5_01546744121._35_6_01699575602. Type type;
				public SourceLevelListItem._32_4_1324018084._34_5_01546744121._35_6_01699575602. Label label;

				public _35_6_01699575602(UnitBox box) {
					super(box);
				}

				@Override
				public void init() {
					super.init();
					if (type == null) type = register(new Type(box()).<Type>id("a_157688036").owner(SourceLevelListItem.this));
					if (label == null) label = register(new Label(box()).<Label>id("a_601478318").owner(SourceLevelListItem.this));
				}

				@Override
				public void unregister() {
				    super.unregister();
					if (type != null) type.unregister();
					if (label != null) label.unregister();
				}

				public class Type extends io.intino.alexandria.ui.displays.components.Text<io.intino.alexandria.ui.displays.notifiers.TextNotifier, UnitBox>  {

					public Type(UnitBox box) {
						super(box);
					}

					@Override
					public void init() {
						super.init();
					}

					@Override
					public void unregister() {
					    super.unregister();
					}
					public Type textColor(String color) {
					    this._textColor(color);
					    this._refreshHighlight();
					    return this;
					}

					public Type backgroundColor(String color) {
					    this._backgroundColor(color);
					    this._refreshHighlight();
					    return this;
					}
				}

				public class Label extends io.intino.alexandria.ui.displays.components.Text<io.intino.alexandria.ui.displays.notifiers.TextNotifier, UnitBox>  {

					public Label(UnitBox box) {
						super(box);
					}

					@Override
					public void init() {
						super.init();
					}

					@Override
					public void unregister() {
					    super.unregister();
					}
				}
			}

			public class Code extends io.intino.alexandria.ui.displays.components.Text<io.intino.alexandria.ui.displays.notifiers.TextNotifier, UnitBox>  {

				public Code(UnitBox box) {
					super(box);
				}

				@Override
				public void init() {
					super.init();
				}

				@Override
				public void unregister() {
				    super.unregister();
				}
			}

			public class TagsCount extends io.intino.alexandria.ui.displays.components.Number<io.intino.alexandria.ui.displays.notifiers.NumberNotifier, UnitBox>  {

				public TagsCount(UnitBox box) {
					super(box);
					label("Tags count");
					_value(0.0);
				}

				@Override
				public void init() {
					super.init();
				}

				@Override
				public void unregister() {
				    super.unregister();
				}
			}
		}

		public class _40_5_0855064589 extends io.intino.alexandria.ui.displays.components.Block<io.intino.alexandria.ui.displays.notifiers.BlockNotifier, UnitBox>  {
			public SourceLevelListItem._32_4_1324018084._40_5_0855064589. GroupFlag groupFlag;

			public _40_5_0855064589(UnitBox box) {
				super(box);
			}

			@Override
			public void init() {
				super.init();
				if (groupFlag == null) groupFlag = register(new GroupFlag(box()).<GroupFlag>id("a737957442").owner(SourceLevelListItem.this));
			}

			@Override
			public void unregister() {
			    super.unregister();
				if (groupFlag != null) groupFlag.unregister();
			}

			public class GroupFlag extends io.intino.alexandria.ui.displays.components.MaterialIcon<io.intino.alexandria.ui.displays.notifiers.MaterialIconNotifier, UnitBox>  {

				public GroupFlag(UnitBox box) {
					super(box);
					_icon("KeyboardArrowRight");
				}

				@Override
				public void init() {
					super.init();
				}

				@Override
				public void unregister() {
				    super.unregister();
				}
			}
		}
	}
}
